========
PyArgCBR
========


.. image:: https://img.shields.io/pypi/v/pyargcbr.svg
        :target: https://pypi.python.org/pypi/pyargcbr

.. image:: https://img.shields.io/travis/jaumejordan/pyargcbr.svg
        :target: https://travis-ci.org/jaumejordan/pyargcbr

.. image:: https://readthedocs.org/projects/pyargcbr/badge/?version=latest
        :target: https://pyargcbr.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status




Case-Based Argumentation Infrastructure in Python


* Free software: MIT license
* Documentation: https://pyargcbr.readthedocs.io.


Features
--------

* Argumentative agents that solve problems reasoning about the possible solutions.
* Domain CBR (Case-based Reasoning) system to store and update domain knowledge.
* Argumentation CBR system to store and update argumentation knowledge of agents.

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
